==> mysql-connector-java-6.0.2-sources.jar: com/mysql/cj/mysqlx/devapi/DevapiRowFactory.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.mysqlx.devapi;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.stream.IntStream;

import com.mysql.cj.core.result.Field;
import com.mysql.cj.mysqlx.result.RowToElement;

/**
 * Create {@link com.mysql.cj.api.x.Row} objects from internal row representation.
 */
public class DevapiRowFactory implements RowToElement<com.mysql.cj.api.x.Row> {
    private Map<String, Integer> fieldNameToIndex;
    private ArrayList<Field> metadata;

    public DevapiRowFactory(ArrayList<Field> metadata) {
        this.metadata = metadata;
    }

    private Map<String, Integer> getFieldNameToIndexMap() {
        if (this.fieldNameToIndex == null) {
            this.fieldNameToIndex = new HashMap<>();
            IntStream.range(0, this.metadata.size()).forEach(i -> this.fieldNameToIndex.put(this.metadata.get(i).getColumnLabel(), i));
        }
        return this.fieldNameToIndex;
    }

    public com.mysql.cj.api.x.Row apply(com.mysql.cj.api.result.Row internalRow) {
        return new RowImpl(internalRow, this::getFieldNameToIndexMap);
    }
}

==> mysql-connector-java-6.0.5-sources.jar: com/mysql/cj/mysqlx/devapi/DevapiRowFactory.java <==
/*
  Copyright (c) 2015, 2016, Oracle and/or its affiliates. All rights reserved.

  The MySQL Connector/J is licensed under the terms of the GPLv2
  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
  this software, see the FOSS License Exception
  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.

  This program is free software; you can redistribute it and/or modify it under the terms
  of the GNU General Public License as published by the Free Software Foundation; version 2
  of the License.

  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with this
  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
  Floor, Boston, MA 02110-1301  USA

 */

package com.mysql.cj.mysqlx.devapi;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import java.util.TimeZone;
import java.util.stream.IntStream;

import com.mysql.cj.core.result.Field;
import com.mysql.cj.mysqlx.result.RowToElement;

/**
 * Create {@link com.mysql.cj.api.x.Row} objects from internal row representation.
 */
public class DevapiRowFactory implements RowToElement<com.mysql.cj.api.x.Row> {
    private Map<String, Integer> fieldNameToIndex;
    private ArrayList<Field> metadata;
    private TimeZone defaultTimeZone;

    public DevapiRowFactory(ArrayList<Field> metadata, TimeZone defaultTimeZone) {
        this.metadata = metadata;
        this.defaultTimeZone = defaultTimeZone;
    }

    private Map<String, Integer> getFieldNameToIndexMap() {
        if (this.fieldNameToIndex == null) {
            this.fieldNameToIndex = new HashMap<>();
            IntStream.range(0, this.metadata.size()).forEach(i -> this.fieldNameToIndex.put(this.metadata.get(i).getColumnLabel(), i));
        }
        return this.fieldNameToIndex;
    }

    public com.mysql.cj.api.x.Row apply(com.mysql.cj.api.result.Row internalRow) {
        return new RowImpl(internalRow, this::getFieldNameToIndexMap, defaultTimeZone);
    }
}
